<?php

class PlacesPage_Controller extends Page_Controller
{
	private static $allowed_actions = [
		'location',
		'placePage'
	];

	private static $url_handlers = [
		'' => 'index',
		'$Action!/$PlaceSlug!' => 'placePage',
		'$Action!' => 'location'
	];
	const PLACE_NOT_FOUND_MESSAGE = 'Place could not be found';
	const REGION_NOT_FOUND_MESSAGE = 'Region could not be found';

	public function index()
	{
		if (!HAS_PLACES_PAGE) {
			return $this->httpError(404, 'Page not found');
		}

		$data = new ArrayData([
			'Places' => Place::get()->filter(['Active' => true]),
			'Region' => false,
			'Categories' => PlaceCategory::get()
		]);
		$this->extend('updatePlacesPage', $data);
		return $this->customise($data)->renderWith(['Places', 'Page']);
	}

	public function placePage()
	{
		$place = Place::get()->filter(['Slug' => $this->getRequest()->param('PlaceSlug')])->first();
		if (!$place) {
			return $this->httpError(404, self::PLACE_NOT_FOUND_MESSAGE);
		}
		if ($place->Region()->Slug !== $this->getRequest()->param('Action')) {
			return $this->httpError(404, self::PLACE_NOT_FOUND_MESSAGE);
		}
		$place->Region = $place->Region();
		$data = $place->getSeoData();
		$data['Places'] = Place::get();
		$data['Region'] = $place->Region()->Slug;
		$data['Place'] = $place;
		$arrayData = new ArrayData($data);
		$this->extend('updatePlace', $arrayData);
		return $this->customise($arrayData)->renderWith(['Place', 'Page']);
	}

	public function location()
	{
		// TODO: SEO and possible location holder page
		if (!HAS_PLACES_PAGE) {
			return $this->httpError(404, 'Page not found');
		}
		$template = USE_PLACES_REGION_TEMPLATE ? 'PlacesLocation' : 'Places';
		$regionName = $this->getRequest()->param('Action');
		$region = Region::get()->filter(['Slug' => $regionName])->first();
		if (!$region) {
			return $this->httpError(404, self::REGION_NOT_FOUND_MESSAGE);
		}
		return $this->customise(new ArrayData([
			'Region' => $region
		]))->renderWith([$template, 'Page']);
	}


}